@@ -47,14 +47,16 @@ function merge_documents(old_doc, new_doc, options) {
         old_doc.documentElement,
         old_doc.head,
         new_doc.head,
-        options,
+        options
     );
     recursive_node_merge(
         old_doc.documentElement,
         old_doc.body,
         new_doc.body,
-        options,
+        options
     );
+
+    old_doc.dispatchEvent(createEvent('elementmergecomplete', false, false, null));
 }
 function merge_whitelist(old_doc, new_doc, options) {
     var whitelist = new_doc.querySelectorAll(options.whitelist);
@@ -130,7 +132,7 @@ function recursive_node_merge(parent, old_node, new_node, options) {
         parent.removeChild(old_node);
         return
     }
-    if (old_node.nodeName != new_node.nodeName || old_node.nodeType == Node.TEXT_NODE) {
+    if (old_node.nodeName != new_node.nodeName || old_node.nodeType == Node.TEXT_NODE || should_replace(old_node, options)) {
         parent.insertBefore(new_node.cloneNode(true), old_node);
         parent.removeChild(old_node);
         return
@@ -207,6 +209,9 @@ function should_skip(old_node, options
     */
     return old_node && old_node.matches && old_node.matches(options.skip);
 }
+function should_replace(old_node, options) {
+    return old_node && old_node.matches && old_node.matches(options.replace);
+}
 
 function get_option_selector(options, option_name) {
     var fixed_value = '[elementmerge-'+option_name+']';
@@ -222,7 +227,15 @@ function with_defaults(options) {
         whitelist: get_option_selector(options, 'whitelist'),
         skip: get_option_selector(options, 'skip'),
         nomerge: get_option_selector(options, 'nomerge'),
+        replace: get_option_selector(options, 'replace'),
     }
 }
 
+function createEvent(name, bubbles, cancelable, detail) {
+    if ( typeof window.CustomEvent === "function" ) return new CustomEvent(name, {bubbles: bubbles, cancelable: cancelable, detail: detail});
+    var event = document.createEvent('CustomEvent');
+    event.initCustomEvent(event, bubbles, cancelable, detail);
+    return event;
+}
+
 })();
\ No newline at end of file
